==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/servicefabricmesh/kotlin/inputs/GetSecretValuePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabricmesh.kotlin.inputs

import com.pulumi.azurenative.servicefabricmesh.inputs.GetSecretValuePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName Azure resource group name
 * @property secretResourceName The name of the secret resource.
 * @property secretValueResourceName The name of the secret resource value which is typically the version identifier for the value.
 */
public data class GetSecretValuePlainArgs(
    public val resourceGroupName: String,
    public val secretResourceName: String,
    public val secretValueResourceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.servicefabricmesh.inputs.GetSecretValuePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.servicefabricmesh.inputs.GetSecretValuePlainArgs =
        com.pulumi.azurenative.servicefabricmesh.inputs.GetSecretValuePlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .secretResourceName(secretResourceName.let({ args0 -> args0 }))
            .secretValueResourceName(secretValueResourceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSecretValuePlainArgs].
 */
@PulumiTagMarker
public class GetSecretValuePlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var secretResourceName: String? = null

    private var secretValueResourceName: String? = null

    /**
     * @param value Azure resource group name
     */
    @JvmName("qufpkieyeyvtenpb")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the secret resource.
     */
    @JvmName("spcmmgrcvpagkwdx")
    public suspend fun secretResourceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.secretResourceName = mapped
    }

    /**
     * @param value The name of the secret resource value which is typically the version identifier for the value.
     */
    @JvmName("tkfkgtciqeevbtcr")
    public suspend fun secretValueResourceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.secretValueResourceName = mapped
    }

    internal fun build(): GetSecretValuePlainArgs = GetSecretValuePlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        secretResourceName = secretResourceName ?: throw PulumiNullFieldException("secretResourceName"),
        secretValueResourceName = secretValueResourceName ?: throw
            PulumiNullFieldException("secretValueResourceName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/servicefabricmesh/kotlin/inputs/GetSecretValuePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabricmesh.kotlin.inputs

import com.pulumi.azurenative.servicefabricmesh.inputs.GetSecretValuePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName Azure resource group name
 * @property secretResourceName The name of the secret resource.
 * @property secretValueResourceName The name of the secret resource value which is typically the version identifier for the value.
 */
public data class GetSecretValuePlainArgs(
    public val resourceGroupName: String,
    public val secretResourceName: String,
    public val secretValueResourceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.servicefabricmesh.inputs.GetSecretValuePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.servicefabricmesh.inputs.GetSecretValuePlainArgs =
        com.pulumi.azurenative.servicefabricmesh.inputs.GetSecretValuePlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .secretResourceName(secretResourceName.let({ args0 -> args0 }))
            .secretValueResourceName(secretValueResourceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSecretValuePlainArgs].
 */
@PulumiTagMarker
public class GetSecretValuePlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var secretResourceName: String? = null

    private var secretValueResourceName: String? = null

    /**
     * @param value Azure resource group name
     */
    @JvmName("jhdpxudnwaycscuv")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the secret resource.
     */
    @JvmName("dpfskltgcewdukfp")
    public suspend fun secretResourceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.secretResourceName = mapped
    }

    /**
     * @param value The name of the secret resource value which is typically the version identifier for the value.
     */
    @JvmName("ttlxpvbapmlehhgo")
    public suspend fun secretValueResourceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.secretValueResourceName = mapped
    }

    internal fun build(): GetSecretValuePlainArgs = GetSecretValuePlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        secretResourceName = secretResourceName ?: throw PulumiNullFieldException("secretResourceName"),
        secretValueResourceName = secretValueResourceName ?: throw
            PulumiNullFieldException("secretValueResourceName"),
    )
}
